==> qore-0.8.13.2.tar.bz2: qore-0.8.13.2/modules/astparser/src/ast/declarations/ASTConstantDeclaration.h <==
/* -*- mode: c++; indent-tabs-mode: nil -*- */
/*
  ASTConstantDeclaration.h

  Qore AST Parser

  Copyright (C) 2017 Qore Technologies, s.r.o.

  Permission is hereby granted, free of charge, to any person obtaining a
  copy of this software and associated documentation files (the "Software"),
  to deal in the Software without restriction, including without limitation
  the rights to use, copy, modify, merge, publish, distribute, sublicense,
  and/or sell copies of the Software, and to permit persons to whom the
  Software is furnished to do so, subject to the following conditions:

  The above copyright notice and this permission notice shall be included in
  all copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  DEALINGS IN THE SOFTWARE.

  Note that the Qore library is released under a choice of three open-source
  licenses: MIT (as above), LGPL 2+, or GPL 2+; see README-LICENSE for more
  information.
*/

#ifndef _QLS_AST_DECLARATIONS_ASTCONSTANTDECLARATION_H
#define _QLS_AST_DECLARATIONS_ASTCONSTANTDECLARATION_H

#include "ast/ASTDeclaration.h"
#include "ast/ASTExpression.h"
#include "ast/ASTModifiers.h"
#include "ast/ASTName.h"

class ASTConstantDeclaration : public ASTDeclaration {
public:
    //! Variable modifiers like \c public or \c our.
    ASTModifiers modifiers;

    //! Name of the constant.
    ASTName name;

    //! Value assigned to the constant.
    ASTExpression::Ptr value;

public:
    ASTConstantDeclaration(ASTModifiers mods, const ASTName& n, ASTExpression* v) :
        ASTDeclaration(),
        modifiers(mods),
        name(n),
        value(v) {}
    ASTConstantDeclaration(const ASTName& n, ASTExpression* v) :
        ASTDeclaration(),
        name(n),
        value(v) {}

    virtual ASTDeclarationKind getKind() const override {
        return ASTDeclarationKind::ADK_Constant;
    }
};

#endif // _QLS_AST_DECLARATIONS_ASTCONSTANTDECLARATION_H

==> qore-1.0.3.tar.bz2: qore-1.0.3/modules/astparser/src/ast/declarations/ASTConstantDeclaration.h <==
/* -*- mode: c++; indent-tabs-mode: nil -*- */
/*
  ASTConstantDeclaration.h

  Qore AST Parser

  Copyright (C) 2017 Qore Technologies, s.r.o.

  Permission is hereby granted, free of charge, to any person obtaining a
  copy of this software and associated documentation files (the "Software"),
  to deal in the Software without restriction, including without limitation
  the rights to use, copy, modify, merge, publish, distribute, sublicense,
  and/or sell copies of the Software, and to permit persons to whom the
  Software is furnished to do so, subject to the following conditions:

  The above copyright notice and this permission notice shall be included in
  all copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  DEALINGS IN THE SOFTWARE.

  Note that the Qore library is released under a choice of three open-source
  licenses: MIT (as above), LGPL 2+, or GPL 2+; see README-LICENSE for more
  information.
*/

#ifndef _QLS_AST_DECLARATIONS_ASTCONSTANTDECLARATION_H
#define _QLS_AST_DECLARATIONS_ASTCONSTANTDECLARATION_H

#include "ast/ASTDeclaration.h"
#include "ast/ASTExpression.h"
#include "ast/ASTModifiers.h"
#include "ast/ASTName.h"

class ASTConstantDeclaration : public ASTDeclaration {
public:
    //! Variable modifiers like \c public or \c our.
    ASTModifiers modifiers;

    //! Name of the constant.
    ASTName name;

    //! Value assigned to the constant.
    ASTExpression::Ptr value;

public:
    ASTConstantDeclaration(ASTModifiers mods, ASTName&& n, ASTExpression* v) :
        ASTDeclaration(),
        modifiers(mods),
        name(std::move(n)),
        value(v) {}
    ASTConstantDeclaration(ASTModifiers mods, const ASTName& n, ASTExpression* v) :
        ASTDeclaration(),
        modifiers(mods),
        name(n),
        value(v) {}

    ASTConstantDeclaration(ASTName&& n, ASTExpression* v) :
        ASTDeclaration(),
        name(std::move(n)),
        value(v) {}
    ASTConstantDeclaration(const ASTName& n, ASTExpression* v) :
        ASTDeclaration(),
        name(n),
        value(v) {}

    virtual ASTDeclarationKind getKind() const override {
        return ASTDeclarationKind::ADK_Constant;
    }
};

#endif // _QLS_AST_DECLARATIONS_ASTCONSTANTDECLARATION_H
